/*
	$Id: Path.java 6600 2014-11-17 07:41:18Z nicklas $

	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.taglib.path;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;
import javax.servlet.http.HttpServletRequest;

import net.sf.basedb.clients.web.taglib.StylableTag;

/**
	This tag defines a navigation path. Usually it is displayed 
	at the top of a page.

	<p>
	<b>Syntax:</b>
	<pre>
   &lt;p:path
      id=...
      clazz=...
      style=...
   &gt;
      &lt;p:pathelement ... /&gt;
   &lt;/p:path&gt;
</pre>

	<p>
	<table border=1 cellspacing=0 cellpadding=2>
	<tr>
		<td><b>Attribute</b></td>
		<td><b>Default value</b></td>
		<td><b>Required</b></td>
		<td><b>Description</b></td>
	</tr>
	<tr>
		<td>id</td>
		<td>-</td>
		<td>yes</td>
		<td>The ID of the path. The value of this attribute
		goes directly into the standard HTML <code>id</code> attribute.
		This means that if you need a reference to the menu object in your own
		JavaScript code, you may for example use the following code:
		<p>
		<code>
		menu = document.getElementById('&lt;id&gt;');
		</code>
		</td>
	</tr>
	<tr>
		<td>clazz</td>
		<td>path</td>
		<td>no</td>
		<td>
			The value if this attribute goes directly into the standard HTML 
			<code>class</code> attribute. This allows you to apply different styles
			to different menus. If you set the type attribute to horizontal you
			should also change this attribute to <code>menu_horizontal</code>.
		</td>
	</tr>
	<tr>
		<td>style</td>
		<td>-</td>
		<td>no</td>
		<td>
			The value if this attribute goes directly into the standard HTML 
			<code>style</code> attribute. This allows you to apply different styles
			to different menus. Note! If you want the menu to be hidden to begin with
			you can use: <code>style="display: none;"</code>.
		</td>
	</tr>
	</table>

	@author Nicklas
	@version 2.0
	@base.modified $Date: 2014-11-17 08:41:18 +0100 (må, 17 nov 2014) $
*/
public class Path 
	extends StylableTag
{

	/**
		
	*/
	private static final long serialVersionUID = 6315346458189900215L;

	/**
		The path to the root directory of this webserver.
	*/
	private static String ROOT = null;


	/**
		Keeps track of the number of path elements so separators can be added.
	*/
	private int numElements;
	
	public Path()
	{
		super("path");
	}
	
	/*
		Taglib initialization methods
	*/

	String getRoot()
	{
		return ROOT;
	}
	
	private String separator = "";
	
	String getSeparator()
	{
		numElements++;
		return numElements > 1 ? separator : "";
	}
	
	@Override
	public int doStartTag()
		throws JspException
	{
		if (ROOT == null) ROOT = ((HttpServletRequest)pageContext.getRequest()).getContextPath()+"/";
		numElements = 0;

		StringBuilder sb = new StringBuilder();
		sb.append("<h1");
		addIdAndStyles(sb);
		addDynamicAttributes(sb);
		sb.append(">");

		try
		{
			pageContext.getOut().print(sb.toString());
    	}
		catch (Exception ex)
		{
			throw new JspTagException(ex.getMessage());
		}
		return EVAL_BODY_INCLUDE;
	}

	@Override
	public int doEndTag() 
		throws JspException
	{
		StringBuilder sb = new StringBuilder();
		sb.append("</h1>\n");
		try
		{
			pageContext.getOut().print(sb.toString());
		}
		catch (Exception ex)
		{
			throw new JspTagException(ex.getMessage());
		}
		return EVAL_PAGE;
	}
}

