/*
	$Id: Rows.java 6183 2012-10-24 11:27:09Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.taglib.table;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;

import net.sf.basedb.clients.web.taglib.StylableTag;

/**
	This tag is a place-holder for {@link Rows &lt;tbl:row&gt;} tags.
	It has no attributes and must be placed inside a {@link Table &lt;tbl:table&gt;}
	tag.

	<p>
	<b>Syntax:</b>
	<pre>
   &lt;tbl:rows&gt;
      &lt;tbl:row ... &gt;
   &lt;/tbl:rows&gt;
</pre>
	<p>
	The <code>&lt;tbl:rows&gt;</code> may contain the following subtags:
	<ul>
	<li>{@link Row &lt;tbl:row&gt;}: Adds a row to the table
	</ul>

	@author Nicklas
	@version 2.0
*/
public class Rows
	extends StylableTag
{


	private static final long serialVersionUID = -2059234250363605715L;

	private Table table;
	
	public Rows()
	{
		super("rows");
	}

	Table getTable()
	{
		return table;
	}
	
	/*
		Display methods
	*/
	@Override
	public int doStartTag()
		throws JspException
	{
		table = (Table)findAncestorWithClass(this, Table.class);
		
		StringBuilder sb = new StringBuilder();
		sb.append("<tbody");
		addIdAndStyles(sb);
		addDynamicAttributes(sb);
		sb.append(">\n");
		try
		{
			pageContext.getOut().print(sb.toString());
		}
		catch (Exception ex)
		{
			throw new JspTagException(ex.getMessage());
		}
		return EVAL_BODY_INCLUDE;
	}
	
	@Override
	public int doEndTag()
		throws JspException
	{
		StringBuilder sb = new StringBuilder();
		sb.append("</tbody>\n");
		try
		{
			pageContext.getOut().print(sb.toString());
		}
		catch (Exception ex)
		{
			throw new JspTagException(ex.getMessage());
		}
		return EVAL_PAGE;
	}

}

