/*
  $Id: DataFileTypeData.java 6127 2012-09-14 07:28:35Z nicklas $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

  BASE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 3
  of the License, or (at your option) any later version.

  BASE is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Set;

/**
	This class hols information about individual files attached
	to items that store data in files instead of in the
	database.
	
	@author Nicklas
	@version 2.5
	@see net.sf.basedb.core.DataFileType
	@base.modified $Date: 2012-09-14 09:28:35 +0200 (fr, 14 sep 2012) $
	@see <a href="../../../../../../html/developer/api/data_api.platforms.html">Developer documentation: Experimental platforms and item subtypes</a>
	@hibernate.class table="`DataFileTypes`" lazy="false"
*/
public class DataFileTypeData
	extends BasicData
	implements NameableData, RemovableData
{

	/*
		From the NameableData interface
		-------------------------------------------
	*/
	private String name;
	@Override
	public String getName()
	{
		return name;
	}
	@Override
	public void setName(String name)
	{
		this.name = name;
	}
	
	private String description;
	@Override
	public String getDescription()
	{
		return description;
	}
	@Override
	public void setDescription(String description)
	{
		this.description = description;
	}
	/*
		-------------------------------------------		
	*/
	
	/*
		From the RemovableData interface
		-------------------------------------------
	*/
	private boolean removed;
	@Override
	public boolean isRemoved()
	{
		return removed;
	}
	@Override
	public void setRemoved(boolean removed)
	{
		this.removed = removed;
	}
	// -------------------------------------------

	/**
		The maximum length of the external ID that can be stored in the database.
		@see #setExternalId(String)
	*/
	public static final int MAX_EXTERNAL_ID_LENGTH = 255;
	private String externalId;
	/**
		Get the external id for the item. 
		@return The external id of the item
		@hibernate.property column="`external_id`" type="string" length="255" 
			not-null="true" update="false" unique="true"
	*/
	public String getExternalId()
	{
		return externalId;
	}
	public void setExternalId(String externalId)
	{
		this.externalId = externalId;
	}
	
	/**
		The maximum length of the file extension that can be stored in the
		database.
	*/
	public static final int MAX_EXTENSION_LENGTH = 255;
	private String extension;
	/**
		Get the extension that files of this type usually have. Null if 
		there is no specific extension.
		@hibernate.property column="extension" type="string" length="255"
	*/
	public String getExtension()
	{
		return extension;
	}
	public void setExtension(String extension)
	{
		this.extension = extension;
	}

	private int itemType;
	/**
		The item type this file type can be associated with.
		@hibernate.property column="`item_type`" type="int" not-null="true" update="false"
	*/
	public int getItemType()
	{
		return itemType;
	}
	public void setItemType(int itemType)
	{
		this.itemType = itemType;
	}
	
	private Set<ItemSubtypeFileTypeData> itemSubtypes;
	/**
		The subtypes that this file type can be used with.

		@hibernate.set lazy="true" inverse="true"
		@hibernate.collection-key column="`datafiletype_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.ItemSubtypeFileTypeData"
	*/
	Set<ItemSubtypeFileTypeData> getItemSubtypes()
	{
		return itemSubtypes;
	}
	void setItemSubtypes(Set<ItemSubtypeFileTypeData> itemSubtypes)
	{
		this.itemSubtypes = itemSubtypes;
	}
	
	private ItemSubtypeData genericType;
	/**
		Get the generic file type of files with this member type.
		@hibernate.many-to-one outer-join="false"
		@hibernate.column name="`filesubtype_id`" not-null="false"
	*/
	public ItemSubtypeData getGenericType()
	{
		return genericType;
	}
	public void setGenericType(ItemSubtypeData genericType)
	{
		this.genericType = genericType;
	}

	private Set<PlatformFileTypeData> platforms;
	/**
		This is the inverse end.
		@see PlatformFileTypeData#getDataFileType()
		@hibernate.set lazy="true" inverse="true" 
		@hibernate.collection-key column="`datafiletype_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.PlatformFileTypeData"
	*/
	Set<PlatformFileTypeData> getPlatforms()
	{
		return platforms;
	}
	void setPlatforms(Set<PlatformFileTypeData> platforms)
	{
		this.platforms = platforms;
	}
	
	private Set<FileSetMemberData> members;
	/**
		This is the inverse end.
		@see FileSetMemberData#getDataFileType()
		@hibernate.set lazy="true" inverse="true" 
		@hibernate.collection-key column="`datafiletype_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.FileSetMemberData"
	*/
	Set<FileSetMemberData> getFileSetMembers()
	{
		return members;
	}
	void setFileSetMembers(Set<FileSetMemberData> members)
	{
		this.members = members;
	}

}
