/*
  $Id $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

/**
	This class holds information about cloned reporter properties.
	
	@author Nicklas
	@since 3.1
	@see net.sf.basedb.core.ReporterCloneTemplate
	@see <a href="../../../../../../html/developer/api/data_api.reporters.html">Developer documentation: Reporters</a>
	@base.modified $Date $
*/
public class ReporterClonePropertyData
{
	public ReporterClonePropertyData()
	{}

	private String title;
	/**
		Get the title of the property.
		@hibernate.property column="`title`" type="string" length="255" not-null="true" update="false" 
	*/
	public String getTitle()
	{
		return title;
	}
	public void setTitle(String title)
	{
		this.title = title;
	}
	
	private String description;
	/**
		Get a description of the property.
		@hibernate.property column="`description`" type="text" not-null="false" update="false" 
	*/
	public String getDescription()
	{
		return description;
	}
	public void setDescription(String description)
	{
		this.description = description;
	}

	
	private int valueType;
	/**
		The code for the value type.
		@hibernate.property column="`value_type`" type="int" not-null="true" update="false"
	*/
	public int getValueType()
	{
		return valueType;
	}
	public void setValueType(int valueType)
	{
		this.valueType = valueType;
	}

	/**
		The maximum length of the column that can be stored in the database.
		@see #setColumn(String)
	*/
	public static final int MAX_COLUMN_LENGTH = 255;
	private String column;
	/**
		Get the name of database column.
		@hibernate.property column="`column`" type="string" length="255" not-null="true" update="false"
	*/
	public String getColumn()
	{
		return column;
	}
	public void setColumn(String column)
	{
		this.column = column;
	}

	private int length;
	/**
		The maximum length of string value types.
		@hibernate.property column="`length`" type="int" not-null="true"
	*/
	public int getLength()
	{
		return length;
	}
	public void setLength(int length)
	{
		this.length = length;
	}

	private boolean nullable;
	/**
		If the column is nullable or not.
		@hibernate.property column="`nullable`" type="boolean" not-null="true" update="false"
	*/
	public boolean isNullable()
	{
		return nullable;
	}
	public void setNullable(boolean nullable)
	{
		this.nullable = nullable;
	}

	private int averageMethod;
	/**
		The code for the averate method to use when calculating averages.
		@hibernate.property column="`average_method`" type="int" not-null="true" update="false"
	*/
	public int getAverageMethod()
	{
		return averageMethod;
	}
	public void setAverageMethod(int averageMethod)
	{
		this.averageMethod = averageMethod;
	}

	private boolean extendedProperty;
	/**
		If the column is an extended or "static" property.
		@hibernate.property column="`extended_property`" type="boolean" not-null="true" update="false"
	*/
	public boolean isExtendedProperty()
	{
		return extendedProperty;
	}
	public void setExtendedProperty(boolean extendedProperty)
	{
		this.extendedProperty = extendedProperty;
	}

	private boolean mandatory;
	/**
		If the column is a mandatory that must be in all clone templates.
		@hibernate.property column="`mandatory`" type="boolean" not-null="true" update="false"
	*/
	public boolean isMandatory()
	{
		return mandatory;
	}
	public void setMandatory(boolean mandatory)
	{
		this.mandatory = mandatory;
	}

}
