/**
	$Id $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.jep;

import java.util.Stack;

import org.nfunk.jep.ParseException;

import net.sf.basedb.util.jep.JepFunction;

/**
	Adds a <code>left(string, index|string)</code> function to Jep. It is used to
	cut out the leftmost characters of a string. If the second argument is a
	number, the string is cut with {@link String#substring(int, int)} with 0 as
	the first argument. If the second argument is a string, the position
	of that string is looked up in the first string and is used as an index.
	Example:
	<pre class="code">
left('foo:bar', 3) == 'foo'
left('foo:bar', ':') == 'foo')
</pre>

	If the second variant is used and the second string is not found within the first,
	the first string is returned unmodified.

	@author nicklas
	@since 3.0
	@base.modified $Date $
*/
public class LeftFunction
	implements JepFunction
{
	
	public LeftFunction()
	{}
	
	/*
		From the JepFunction interface
		-------------------------------------------
	*/
	/**
		@return The string "left"
	*/
	@Override
	public String getFunctionName()
	{
		return "left";
	}
	// -------------------------------------------
	/*
		From the PostfixMathCommandI interface
		-------------------------------------------
	*/
	/**
		@return Always 2
	*/
	@Override
	public int getNumberOfParameters()
	{
		return 2;
	}
	@Override
	public void setCurNumberOfParameters(int n)
	{}
	@Override
	public boolean checkNumberOfParameters(int n)
	{
		return n == 2;
	}
	@Override
	@SuppressWarnings({"unchecked"})
	public void run(Stack stack)
		throws ParseException
	{
		if (stack == null || stack.empty()) 
		{
			throw new ParseException("Stack is empty");
		}
		Object arg2 = stack.pop();
		Object arg1 = stack.pop();
		
		String s1 = arg1.toString();
		int index = 0;
		if (arg2 instanceof Number)
		{
			index = ((Number)arg2).intValue();
		}
		else
		{
			index = s1.indexOf(arg2.toString());
		}
		stack.push(index < 0 ? s1 : s1.substring(0, index));
	}
	// -------------------------------------------


}
