/**
	$Id $

	Copyright (C) 2014 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.json;

import org.json.simple.JSONObject;

import net.sf.basedb.core.Nameable;


/**
	Simple "converter" implementation that create JSON objects
	with the name and id of {@link Nameable} items. Subclasses
	may implement the {@link #setMore(JSONObject, Nameable)} method
	to add more properties to the JSON object.
	
	@author nicklas
	@since 3.3
*/
public class NameableConverter<T extends Nameable>
	implements JsonConverter<T>
{

	public NameableConverter()
	{}
	
	/**
		@return The JSON object
	*/
	@SuppressWarnings("unchecked")
	@Override
	public Object convert(T object)
	{
		JSONObject json = new JSONObject();
		json.put("id", object.getId());
		json.put("name", object.getName());
		setMore(json, object);
		return json;
	}
	
	/**
		Can be used by subclasses to set more properties on the
		JSON object. The default implementation does nothing.
		@param json The JSON object that store the converted properties
		@param object The object that is being converted
	*/
	protected void setMore(JSONObject json, T object)
	{}
	
}
