/**
	$Id$

	Copyright (C) 2015 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.listable;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import net.sf.basedb.core.Item;
import net.sf.basedb.core.SyncFilter.SourceItemTransform;

/**
	Abstract base class for source item transformer factories that can be useful
	for implementing some common functionality.
	
	@author Nicklas
	@since 3.5
*/
public abstract class AbstractSourceItemTransformerFactory
	implements SourceItemTransformerFactory 
{

	private final Item target;
	private final List<Item> parentToChild;
	private final List<Item> childToParent;
	
	/**
		Create a new instance supports transformation between the given
		source items and target item.
		@param target The supported target item type
		@param parentToChild The supported source item types for {@link SourceItemTransform#PARENT_TO_CHILD} transform
		@param childToParent The supported source item types for {@link SourceItemTransform#CHILD_TO_PARENT} transform
	*/
	protected AbstractSourceItemTransformerFactory(Item target, Item[] parentToChild, Item[] childToParent) 
	{
		this.target = target;
		this.parentToChild = Collections.unmodifiableList(Arrays.asList(parentToChild));
		this.childToParent = Collections.unmodifiableList(Arrays.asList(childToParent));
	}
	
	@Override
	public Item getTargetItem() 
	{
		return target;
	}

	@Override
	public List<Item> getSupportedSourceItems(SourceItemTransform transform) 
	{
		List<Item> supported = null;
		if (transform == SourceItemTransform.PARENT_TO_CHILD)
		{
			supported = parentToChild;
		}
		else if (transform == SourceItemTransform.CHILD_TO_PARENT)
		{
			supported = childToParent;
		}
		return supported;
	}
	
}
