/**
	$Id$

	Copyright (C) 2015 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.listable;

import java.util.Set;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.ItemQuery;
import net.sf.basedb.core.RawBioAssay;
import net.sf.basedb.core.query.Expressions;
import net.sf.basedb.core.query.Hql;
import net.sf.basedb.core.query.Restrictions;

/**
	Source item transformer implementation that transform derived bioassay items 
	to raw bioassays.
	
	@author Nicklas
	@since 3.5
*/
public class DerivedBioAssayToRawBioAssayTransformer 
	extends AbstractSourceItemTransformer
{

	private CollectExtracts collectedExtracts;

	/**
		Create a new derived bioassay to raw bioassay transformer.
	*/
	public DerivedBioAssayToRawBioAssayTransformer() 
	{
		super(Item.DERIVEDBIOASSAY, Item.RAWBIOASSAY);
	}
	
	/**
		Create a new derived bioassay to raw bioassay transformer that also
		consider collected parent extracts.
	*/
	public DerivedBioAssayToRawBioAssayTransformer(CollectExtracts collectedExtracts) 
	{
		this();
		this.collectedExtracts = collectedExtracts;
	}

	
	@Override
	public Set<Integer> transform(TransformContext context, Set<Integer> source) 
	{
		DbControl dc = context.getDbControl();
		
		ItemQuery<RawBioAssay> query = RawBioAssay.getQuery();
		query.setIncludes(context.getInclude());
		query.join(Hql.innerJoin("parentBioAssay", "dba"));
		query.restrict(
			Restrictions.in(
				Hql.alias("dba"), 
				Expressions.parameter("bioAssays")
			)
		);
		Set<Integer> all = safeIdList(dc, query, "bioAssays", source);
		
		if (collectedExtracts != null)
		{
			query = RawBioAssay.getQuery();
			query.setIncludes(context.getInclude());
			query.join(Hql.leftJoin("parentExtract", "xtr"));
			query.restrict(Restrictions.or(
				Restrictions.eq(Hql.alias("xtr"), null),
				Restrictions.in(Hql.alias("xtr"), Expressions.parameter("extracts"))
			));
			all.retainAll(safeIdList(dc, query, "extracts", collectedExtracts.getCollected()));
		}
		
		return all;
	}

}
