/**
	$Id$

	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.extensions;

import java.lang.reflect.Field;

import net.sf.basedb.util.ClassUtil;
import net.sf.basedb.util.extensions.ActionFactory;
import net.sf.basedb.util.extensions.InvokationContext;

/**
	Factory implementation for validation rule actions that uses reflection
	to access the value of a public static field and return that as the validation
	rule. The public static field must be a {@link ValidationRuleAction} object.
	<p>
	This factory has one configuration parameter <code>field</code> which is
	the fully qualified name for the field. Failure to access or use the class and/or 
	field disabled the action and is reported to the log only.
	
	@author nicklas
	@since 3.2
*/
public class ReflectValidationRuleActionFactory 
	implements ActionFactory<ValidationRuleAction>
{

	private String fullFieldName;
	private ValidationRuleAction rule;
	
	public ReflectValidationRuleActionFactory()
	{}
	
	/*
		From the ActionFactory interface
		--------------------------------
	*/
	@Override
	public boolean prepareContext(InvokationContext<? super ValidationRuleAction> context) 
	{
		return getValidationRule(context) != null;
	}

	@Override
	public ValidationRuleAction[] getActions(InvokationContext<? super ValidationRuleAction> context) 
	{
		return new ValidationRuleAction[] { rule };
	}
	// ----------------------------------
	
	
	public void setField(String fullFieldName)
	{
		this.fullFieldName = fullFieldName;
	}
	
	private ValidationRuleAction getValidationRule(InvokationContext context)
	{
		if (rule == null && fullFieldName != null) 
		{
			int lastDot = fullFieldName.lastIndexOf('.');
			String clazzName = fullFieldName.substring(0, lastDot);
			String fieldName = fullFieldName.substring(lastDot+1);
			
			try
			{
				Class clazz = ClassUtil.checkAndLoadClass(context.getClassLoader(), clazzName, false);
				Field ruleField = clazz.getField(fieldName);
				rule = (ValidationRuleAction)ruleField.get(null);
			}
			catch (Exception ex)
			{
				ex.printStackTrace();
				fullFieldName = null;
			}
		}
		return rule;
	}
}
