/**
	$Id$

	Copyright (C) 2014 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.uri;

import java.io.IOException;
import java.io.InputStream;

/**
	An extension to the {@link ConnectionManager} interface that
	add support for specifying a start offset when downloading the
	external file. If the external protocol has support for setting
	a start offset it is recommended that connection managers are
	implementing this interface, since otherwise the BASE core may
	simply read to the specified offset which is wasting bandwith.

	@author Nicklas
	@since 3.3
*/
public interface ResumableConnectionManager
	extends ConnectionManager
{

	/**
		Get an InputStream for reading the contents of the resource.
		@param offset The offset to start reading from
		@return An InputStream object, or null if the no data is available
		@throws IOException If there is an error creating the stream
	*/
	public InputStream getInputStream(long offset)
		throws IOException;
	
}

