/*
	$Id: TestSessionControl.java 5827 2011-10-26 10:51:52Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
import net.sf.basedb.core.*;

public class TestSessionControl
{

	static boolean ok = true;
	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		ok = test_all();
		TestUtil.stop();
	}

	static boolean test_all()
	{
		write("++Testing SessionControl");
		test_get_session_control(TestUtil.getLocalIp(), false);
		test_get_session_control("unknown.ip.address", true);
		test_user_default_setting("test.default", "This is the users default setting");
		test_user_client_setting("test.client", "This is the users client setting");
		int userId = TestUser.test_create(true);
		test_impersonate(userId);
		TestUser.test_delete(userId);
		write("++Testing SessionControl "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}

	static void test_get_session_control(String remoteId, boolean shouldFail)
	{
		SessionControl sc = TestUtil.getSessionControl();
		try
		{
			Application.getSessionControl(sc.getId(), remoteId);
			if (shouldFail) 
			{
				write("--Get SessionControl FAILED (Expected exception)");
				ok = false;
			}
			else
			{
				write("--Get SessionControl OK");
			}
		}
		catch (Throwable ex)
		{
			if (shouldFail)
			{
				write("--Get SessionControl OK (Expected exception: "+ex.getMessage());
			}
			else
			{
				write("--Get SessionControl FAILED");
				ex.printStackTrace();
				ok = false;
			}
		}
	}
	
	static void test_user_default_setting(String name, String value)
	{
		SessionControl sc = TestUtil.getSessionControl();
		try
		{
			String oldValue = sc.getUserDefaultSetting(name);
			if (!TestUtil.getSilent()) write("Setting "+name+"="+oldValue);
			sc.setUserDefaultSetting(name, value);
			if (!TestUtil.getSilent()) write("Setting "+name+"="+sc.getUserDefaultSetting(name));
			TestUtil.logout();
			TestUtil.login();
			String newValue = sc.getUserDefaultSetting(name);
			if (!TestUtil.getSilent()) write("Setting "+name+"="+newValue);
			if (!value.equals(newValue)) throw new BaseException("New value != value");
			sc.setUserDefaultSetting(name, oldValue);
			write("--Test user default setting OK");
		}
		catch (Throwable ex)
		{
			write("--Test user default setting FAILED");
			ex.printStackTrace();
			ok = false;
		}
	}
	
	static void test_user_client_setting(String name, String value)
	{
		SessionControl sc = TestUtil.getSessionControl();
		try
		{
			String oldValue = sc.getUserClientSetting(name);
			if (!TestUtil.getSilent()) write("Setting "+name+"="+oldValue);
			sc.setUserClientSetting(name, value);
			if (!TestUtil.getSilent()) write("Setting "+name+"="+sc.getUserClientSetting(name));
			TestUtil.logout();
			TestUtil.login();
			String newValue = sc.getUserClientSetting(name);
			if (!TestUtil.getSilent()) write("Setting "+name+"="+newValue);
			if (!value.equals(newValue)) throw new BaseException("New value != value");
			sc.setUserClientSetting(name, oldValue);
			write("--Test user client setting OK");
		}
		catch (Throwable ex)
		{
			write("--Test user client setting FAILED");
			ex.printStackTrace();
			ok = false;
		}
	}

	static void test_impersonate(int userId)
	{
		if (userId == 0) return;
		SessionControl sc = TestUtil.getSessionControl();
		try
		{
			SessionControl impersonated = sc.impersonateLogin(userId, "Testing impersonation");
			if (!TestUtil.getSilent()) write("We are now impersonated. Logged in as: " 
				+ impersonated.getLoggedInUserId() + "; impersonated = " + impersonated.isImpersonated());
			impersonated.logout();
			write("--Impersonate OK");
		}
		catch (Throwable ex)
		{
			write("--Impersonate FAILED");
			ex.printStackTrace();
			ok = false;
		}
	}

	static void write(String message)
	{
		System.out.println(message);
	}

}

