/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var Calendar = function()
{
	var dateField;
	var dateFormat;
	var useTime;
	var currentDate;
	var calendarYear;
	var calendarMonth;
	
	var calendar = {};
	calendar.MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 
	                   'July', 'August', 'September', 'October', 'November', 'December'];
	
	calendar.initPage = function()
	{
		// Dialog buttons
		Buttons.addClickHandler('close', App.closeWindow);
		Buttons.addClickHandler('btnSave', Calendar.save);
		Buttons.addClickHandler('btnToday', Calendar.setToday);
		
		// Next and previous month
		Buttons.addClickHandler('nextMonth', calendar.nextMonth);
		Buttons.addClickHandler('prevMonth', calendar.prevMonth);
		
		// Time controls
		Events.addEventHandler('hours', 'keypress', Events.integerOnly);
		Events.addEventHandler('minutes', 'keypress', Events.integerOnly);
		Events.addEventHandler('seconds', 'keypress', Events.integerOnly);
		
		// Each day in the calendar; 6 weeks max
		// Add a normal click handler and an extra for moving focus with arrow keys
		for (var week = 1; week < 7; week++)
		{
			for (var day = 0; day < 7; day++)
			{
				var e = 'w'+week+'d'+day;
				Buttons.addClickHandler(e, calendar.dayOnClick);
				Events.addEventHandler(e, 'keypress', calendar.handleArrowKeys);
			}
		}
		
		// Get the field that holds the date value in the parent form
		dateField = window.opener.document.getElementById(Data.get('page-data', 'textarea'));
		dateFormat = Data.get('page-data', 'date-format');
		useTime = Data.int('page-data', 'use-time');
		currentDate = Dates.parseString(dateField.value, dateFormat);
		if (!currentDate) currentDate = new Date();
		
		// Display the current month and time
		calendar.displayMonth(currentDate.getFullYear(), currentDate.getMonth());
		if (useTime)
		{
			var frm = document.forms['calendar'];
			frm.hours.value = calendar.zeroPad(currentDate.getHours());
			frm.minutes.value = calendar.zeroPad(currentDate.getMinutes());
			frm.seconds.value = calendar.zeroPad(currentDate.getSeconds());
		}
	}

	/**
		Display a calendar for the given year and month.
	*/
	calendar.displayMonth = function(year, month)
	{
		// Normalize month and year
		if (month > 11)
		{
			month -= 12;
			year++;
		}
		else if (month < 0)
		{
			month += 12;
			year--;
		}
		calendarMonth = month;
		calendarYear = year;
		
		// Display the year and month
		Doc.element('year').innerHTML = year;
		Doc.element('month').innerHTML = calendar.MONTHS[month];
		
		// The day of week of the first day in month
		// 1=mon, 2=tue, ...7=sun
		var firstDayInMonth = new Date(year, month, 1).getDay() || 7;
		// Number of day in this month
		var daysInMonth = Dates.daysInMonth(year, month+1);
		var dayNum = 2-firstDayInMonth;
		var today = new Date();
		for (var week = 1; week <= 6; week++)
		{
			for (var day = 0; day <= 6; day++)
			{
				var cell = Doc.element('w'+week+'d'+day);
				{
					if (dayNum < 1 || dayNum > daysInMonth)
					{
						cell.firstChild.nodeValue = '';
						cell.tabIndex = -1;
						cell.theDate = null;
						Doc.removeClass(cell, 'interactable');
						if (day == 0 && week > 4) Doc.hide('w' + week);
					}
					else
					{
						cell.firstChild.nodeValue = dayNum;
						cell.tabIndex = 0;
						cell.theDate = new Date(year, month, dayNum);
						Doc.addClass(cell, 'interactable');
						if (day == 0) Doc.show('w' + week);
					}
				}
				// Mark today's date
				if (year == today.getFullYear() && month == today.getMonth() && dayNum == today.getDate())
				{
					Doc.addClass(cell, 'today');
				}
				else
				{
					Doc.removeClass(cell, 'today');
				}
				// Mark the currently selected date
				if (year == currentDate.getFullYear() && month == currentDate.getMonth() && dayNum == currentDate.getDate())
				{
					Doc.addClass(cell, 'active');
					cell.focus();
				}
				else
				{
					Doc.removeClass(cell, 'active');
				}
				dayNum++;
			}
		}
		
	}
	
	// Add an extra '0' to all values below 10.
	calendar.zeroPad = function(value)
	{
		return value <= 9 ? '0' + value : value;
	}
	
	/**
		Display the next month in the calendar.
	*/
	calendar.nextMonth = function()
	{
		calendar.displayMonth(calendarYear, calendarMonth+1);
	}
	
	/**
		Display the previous month in the calendar.
	*/
	calendar.prevMonth = function()
	{
		calendar.displayMonth(calendarYear, calendarMonth-1);
	}
	
	/**
		Set the current date as the date and close the
		calendar.
	*/
	calendar.setToday = function()
	{
		currentDate = new Date();
		if (useTime)
		{
			calendar.displayMonth(currentDate.getFullYear(), currentDate.getMonth());
		}
		else
		{
			calendar.save();
		}
	}
	
	/**
		Check that a valid date (and time) has been set.
	*/
	calendar.validate = function()
	{
		var frm = document.forms['calendar'];
		if (useTime)
		{
			var hours = parseInt(frm.hours.value, 10);
			if (hours < 0 || hours > 23)
			{
				Forms.showNotification(frm.hours, 'Hours must be a value between 0 and 23', 'small');
				return false;
			}
			var minutes = parseInt(frm.minutes.value, 10);
			if (minutes < 0 || minutes > 59)
			{
				Forms.showNotification(frm.minutes, 'Minutes must be a value between 0 and 59', 'small');
				return false;
			}
			var seconds = parseInt(frm.seconds.value, 10);
			if (seconds < 0 || seconds > 59)
			{
				Forms.showNotification(frm.seconds, 'Seconds must be a value between 0 and 59', 'small');
				return false;
			}
		}
		return true;
	}
	
	calendar.save = function()
	{
		// Validate form
		if (!calendar.validate()) return;
		
		// Copy current time values
		if (useTime)
		{
			var frm = document.forms['calendar'];
			currentDate.setHours(frm.hours.value);
			currentDate.setMinutes(frm.minutes.value);
			currentDate.setSeconds(frm.seconds.value);
		}
		
		// Save the value to the date field
		dateField.value = Dates.formatDate(currentDate, dateFormat);
		// Fire an 'onchange' event
		Events.sendChangeEvent(dateField);
		// Set the focus...
		dateField.focus();
		// ...and close the calendar
		window.close();
	}
	
	/**
		Event handler for 'click' events on a day in the calendar.
		Saves the clicked date and closes the calendar (if no time 
		is used).
	*/
	calendar.dayOnClick = function(event)
	{
		if (!event.currentTarget.theDate) return;
		currentDate = event.currentTarget.theDate;
		if (useTime)
		{
			calendar.displayMonth(currentDate.getFullYear(), currentDate.getMonth());
		}
		else
		{
			calendar.save();
		}
	}
	
	/**
		Set focus to 'next' day when arrow keys are pressed.
	*/
	calendar.handleArrowKeys = function(event)
	{
		var keyCode = event.keyCode;
		if (keyCode >= 37 && keyCode <= 40)
		{
			var week = Data.int(event.currentTarget, 'week');
			var day = Data.int(event.currentTarget, 'day');
			// 37 - left, 38 - up, 39 - right, 40 - down
			if (keyCode == 37) day--;
			if (keyCode == 38) week--;
			if (keyCode == 39) day++;
			if (keyCode == 40) week++;
			var next = Doc.element('w'+week+'d'+day);
			if (next && next.tabIndex != -1)
			{
				next.focus();
			}
		}
	}
	
	return calendar;
}();

Doc.onLoad(Calendar.initPage);


